@@ -15,7 +15,7 @@ from django.db import models
 from django.utils.deconstruct import deconstructible
 from django.utils.encoding import force_text
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from fido2.ctap2 import AttestationObject, AttestedCredentialData
 from OpenSSL import crypto
 
